@@ -16,15 +16,15 @@ OC.L10N.register(
     "can edit" : "posuple eo embann",
     "Add" : "Ouzhpennañ",
     "Display name" : "Anv ardivink",
-    "Password protection" : "Gwareziñ gant ur ger-tremen",
     "Save" : "Enrollañ",
-    "Description" : "Deskrivadur",
-    "Cancel" : "Arrest",
+    "Cancel" : "Nullañ",
     "Invalid image" : "N'eo ket aotreet ar skeudenn",
     "Name" : "Anv",
     "Title" : "Titl",
     "Company" : "Embregerez",
+    "View profile" : "Gwelet ar profil",
     "Search contacts …" : "Klask darempred ...",
+    "Search for people to add" : "Klask tud da ouzhpennañ",
     "No results" : "Disoc'h ebet",
     "Pending" : "O c'hortoz",
     "None" : "Hini ebet",
@@ -35,7 +35,10 @@ OC.L10N.register(
     "Email" : "Postel",
     "Admin" : "Merour",
     "Owner" : "Perc'henner",
-    "Website" : "Lec'hien web",
+    "Privacy" : "Prevezder",
+    "Nickname" : "Lesanv",
+    "Notes" : "Notennoù",
+    "Website" : "Lec'hienn web",
     "Location" : "Lec'hiadur",
     "Home" : "Degemer",
     "Work" : "Labour",
@@ -44,6 +47,10 @@ OC.L10N.register(
     "City" : "Ker",
     "Country" : "Bro",
     "Birthday" : "Deiz-ha-bloaz",
-    "Unknown" : "Dianv"
+    "Brother" : "Breur",
+    "Sister" : "C'hoar",
+    "Unknown" : "Dianv",
+    "Password protection" : "Gwareziñ gant ur ger-tremen",
+    "Description" : "Deskrivadur"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
