@@ -88,31 +88,25 @@ OC.L10N.register(
     "Sort by {sorting}" : "{sorting} で整列",
     "Manages" : "管理",
     "Oversees" : "統括",
-    "An error happened during the config change" : "構成の変更中にエラーが発生しました",
-    "Password protection" : "パスワード保護",
     "Enforce password protection on files shared to this team" : "このチームと共有するファイルにパスワード保護を強制します",
     "Use a unique password for all shares to this team" : "このチームのすべての共有に一意のパスワードを使用します",
     "Unique password …" : "固有パスワード...",
     "Save" : "保存",
     "Change unique password" : "固有パスワードを変更",
     "Failed to save password. Please try again later." : "パスワードを保存できませんでした。後でもう一度やり直してください",
+    "An error happened during the config change" : "構成の変更中にエラーが発生しました",
     "There is no description for this team" : "このチームの説明はありません",
     "Enter a description for the team" : "チームの説明を入力します",
     "An error happened during description sync" : "説明の同期中にエラーが発生しました",
     "An error happened during name sync" : "名前の同期中にエラーが発生しました",
-    "Team owned by {owner}" : "{owner}が所有するチーム",
-    "Team settings" : "チーム設定",
+    "Team name" : "チーム名",
+    "Edit" : "編集",
+    "Cancel" : "キャンセル",
     "Request to join" : "参加リクエスト",
-    "Description" : "詳細",
     "Your request to join this team is pending approval" : "このチームへの参加リクエストは承認待ちです",
     "You are not a member of {circle}" : "あなたはサークル{circle}のメンバーではありません",
-    "Team resources" : "チームのリソース",
-    "Anything shared with this team will show up here" : "このチームと共有されているものはすべてここに表示されます",
-    "Team name" : "チーム名",
-    "Settings" : "Settings",
-    "Actions" : "アクション",
+    "Members" : "メンバー",
     "Confirm" : "承認",
-    "Cancel" : "キャンセル",
     "Add more info" : "さらに情報を追加",
     "More fields" : "その他のフィールド",
     "Please select a valid format" : "有効なフォーマットを選択してください。",
@@ -149,7 +143,6 @@ OC.L10N.register(
     "Go to talk conversation" : "Talkのチャットへ移動",
     "View profile" : "プロフィールを表示",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "この連絡先は変更され、修正を受信しました。内容を確認してクリックで保存してください。",
-    "Edit" : "編集",
     "Clone contact" : "連絡先の複製",
     "Generate QR Code" : "QRコードを生成",
     "Contact vCard as QR code" : "QRコードでの連絡先vCard",
@@ -174,16 +167,6 @@ OC.L10N.register(
     "Local team" : "ローカルチーム",
     "This team will not be shared with the other instances of the global scale" : "このチームはグローバルスケールの他のインスタンスと共有されません",
     "Create team" : "チームを作成する",
-    "Unable to get the results" : "結果を取得できません",
-    "Some members could not be added" : "一部のメンバーを追加できませんでした",
-    "There was an issue adding members to the team" : "チームへのメンバーの追加で問題が発生しました",
-    "Team members" : "チームのメンバー",
-    "Loading members list …" : "メンバーリストを読み込んでいます…",
-    "The list of members is only visible to members of this team" : "メンバーのリストは、このチームのメンバーにのみ表示されます",
-    "You currently have no access to the member list" : "メンバーリストへのアクセス権がありません",
-    "Add members" : "メンバーの追加",
-    "Add to {circle}" : "{circle} に追加",
-    "Pending" : "保留中",
     "Promote as sole owner" : "唯一の所有者に昇格",
     "Promote to {level}" : "{level}に昇格",
     "Demote to {level}" : "{level}に降格",
@@ -194,6 +177,14 @@ OC.L10N.register(
     "Reject membership request" : "メンバーシップリクエストを拒否",
     "Manage level" : "レベルを管理",
     "Remove member" : "メンバーを削除",
+    "Unable to get the results" : "結果を取得できません",
+    "Some members could not be added" : "一部のメンバーを追加できませんでした",
+    "There was an issue adding members to the team" : "チームへのメンバーの追加で問題が発生しました",
+    "Loading members list …" : "メンバーリストを読み込んでいます…",
+    "The list of members is only visible to members of this team" : "メンバーのリストは、このチームのメンバーにのみ表示されます",
+    "You currently have no access to the member list" : "メンバーリストへのアクセス権がありません",
+    "Add to {circle}" : "{circle} に追加",
+    "Pending" : "保留中",
     "Select chart …" : "組織図を選択...",
     "Chart" : "チャート",
     "Select Date" : "日付を選択",
@@ -201,10 +192,12 @@ OC.L10N.register(
     "Add contact in group" : "グループに連絡先を追加",
     "None" : "なし",
     "Select option" : "オプションを選択",
+    "Personal dates" : "個人的な日程",
     "Add property of this type" : "このタイプのプロパティーを追加",
     "Unable to create the contact." : "連絡先を追加できません。",
     "Contact not found" : "連絡先がありません",
     "Group {group} not found" : "グループ {group} が見つかりません",
+    "Add member" : "メンバーの追加",
     "New contact" : "新しい連絡先",
     "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 件の連絡先を {name} に追加しました"],
     "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{success} 件の連絡先を {name} に追加中"],
@@ -245,10 +238,8 @@ OC.L10N.register(
     "Members need to accept invitation" : "メンバーは招待を承認する必要があります",
     "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "メンバシップはモデレータによって確認/承認される必要があります (「誰でもメンバシップをリクエストできます」が必要) 。",
     "Members can also invite" : "メンバーによる招待も可能",
-    "Visibility" : "公開レベル",
-    "Visible to everyone" : "すべての人に公開",
-    "Team membership" : "チームのメンバー",
     "Prevent teams from being a member of another team" : "チームが別のチームのメンバーになることを禁止する",
+    "Visible to everyone" : "すべての人に公開",
     "users" : "ユーザー",
     "Users" : "ユーザー",
     "groups" : "グループ",
@@ -322,10 +313,17 @@ OC.L10N.register(
     "Unable to create team {circleName}" : "チーム{circleName}を作成できません",
     "Unable to delete team {circleId}" : "チーム {circleId} を削除できません",
     "Unable to delete contact" : "連絡先を削除できません。",
-    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "メンバーシップは、モデレーターにより確認/承認が必要です（開く要求）",
-    "Manager" : "マネージャー",
-    "Members" : "メンバー",
-    "Manage members" : "メンバーの管理",
-    "Show team details" : "チームの詳細を表示"
+    "Password protection" : "パスワード保護",
+    "Team owned by {owner}" : "{owner}が所有するチーム",
+    "Team settings" : "チーム設定",
+    "Description" : "詳細",
+    "Team resources" : "チームのリソース",
+    "Anything shared with this team will show up here" : "このチームと共有されているものはすべてここに表示されます",
+    "Settings" : "Settings",
+    "Actions" : "アクション",
+    "Team members" : "チームのメンバー",
+    "Add members" : "メンバーの追加",
+    "Visibility" : "公開レベル",
+    "Team membership" : "チームのメンバー"
 },
 "nplurals=1; plural=0;");
