@@ -68,19 +68,17 @@ OC.L10N.register(
     "Display name" : "표시 이름",
     "Last modified" : "수정한 날짜",
     "Sort by {sorting}" : "{sorting}(으)로 정렬",
-    "An error happened during the config change" : "변경 사항을 설정하는 중 오류 발생",
-    "Password protection" : "암호 보호",
     "Unique password …" : "독자 암호 ...",
     "Save" : "저장",
     "Change unique password" : "독자 암호 변경",
     "Failed to save password. Please try again later." : "암호를 저장하는 데 실패했습니다. 잠시 후 다시 시도하십시오.",
+    "An error happened during the config change" : "변경 사항을 설정하는 중 오류 발생",
     "An error happened during description sync" : "설명 동기화 중 오류 발생",
     "An error happened during name sync" : "이름 동기화 중 오류 발생",
-    "Request to join" : "등록 요청",
-    "Description" : "설명",
-    "You are not a member of {circle}" : "당신은 {circle}의 회원이 아닙니다.",
-    "Settings" : "Settings",
+    "Edit" : "편집",
     "Cancel" : "취소",
+    "Request to join" : "등록 요청",
+    "You are not a member of {circle}" : "당신은 {circle}의 회원이 아닙니다.",
     "Add more info" : "정보 추가",
     "More fields" : "더 많은 입력란",
     "Please select a valid format" : "유효한 형식을 선택하십시오",
@@ -116,7 +114,6 @@ OC.L10N.register(
     "Go to talk conversation" : "Talk 대화로 이동",
     "View profile" : "프로필 보기",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "연락처가 잘못되었으며 수정이 필요합니다. 내용을 점검하고 여기를 눌러 저장하십시오.",
-    "Edit" : "편집",
     "Clone contact" : "연락처 복제",
     "Generate QR Code" : "QR 코드 생성",
     "Contact vCard as QR code" : "QR 코드로 된 vCard 연락처",
@@ -134,13 +131,6 @@ OC.L10N.register(
     "Search for people to add" : "추가할 사람 검색",
     "No results" : "결과 없음",
     "Add {type}" : "{type} 추가",
-    "Unable to get the results" : "결과를 받아올 수 없음",
-    "Some members could not be added" : "일부 회원을 추가할 수 없음",
-    "Loading members list …" : "회원 목록 불러오는 중 ...",
-    "You currently have no access to the member list" : "현재 이 구성원 목록에 접근할 수 없습니다",
-    "Add members" : "회원 추가",
-    "Add to {circle}" : "{circle}에 추가",
-    "Pending" : "보류 중",
     "Promote as sole owner" : "단독 소유 권한 부여",
     "Promote to {level}" : "{level}(으)로 진급",
     "Demote to {level}" : "{level}(으)로 강등",
@@ -151,6 +141,12 @@ OC.L10N.register(
     "Reject membership request" : "가입 요청 거절",
     "Manage level" : "레벨 관리",
     "Remove member" : "회원 삭제",
+    "Unable to get the results" : "결과를 받아올 수 없음",
+    "Some members could not be added" : "일부 회원을 추가할 수 없음",
+    "Loading members list …" : "회원 목록 불러오는 중 ...",
+    "You currently have no access to the member list" : "현재 이 구성원 목록에 접근할 수 없습니다",
+    "Add to {circle}" : "{circle}에 추가",
+    "Pending" : "보류 중",
     "Select chart …" : "차트 선택 ...",
     "Chart" : "차트",
     "Select Date" : "날짜 선택",
@@ -190,7 +186,7 @@ OC.L10N.register(
     "Anyone can request membership" : "누구나 가입을 요청할 수 있음",
     "Members need to accept invitation" : "회원이 초대를 수락해야 함",
     "Members can also invite" : "회원도 초대 가능",
-    "Visibility" : "표시 여부",
+    "Privacy" : "개인 정보",
     "Visible to everyone" : "모두에게 보이기",
     "Email addresses" : "이메일 주소",
     "Detailed name" : "자세한 이름",
@@ -251,6 +247,11 @@ OC.L10N.register(
     "Time zone" : "시간대",
     "Spoken languages" : "사용 언어",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["연락처 {failed}개를 읽을 수 없음"],
-    "Unable to delete contact" : "연락처를 삭제할 수 없음"
+    "Unable to delete contact" : "연락처를 삭제할 수 없음",
+    "Password protection" : "암호 보호",
+    "Description" : "설명",
+    "Settings" : "Settings",
+    "Add members" : "회원 추가",
+    "Visibility" : "표시 여부"
 },
 "nplurals=1; plural=0;");
