@@ -88,31 +88,26 @@ OC.L10N.register(
     "Sort by {sorting}" : "以 {sorting} 排序",
     "Manages" : "管理",
     "Oversees" : "监督",
-    "An error happened during the config change" : "更改配置时发生一个错误",
-    "Password protection" : "密码保护",
     "Enforce password protection on files shared to this team" : "对与此团队共享的文件强制实施密码保护",
     "Use a unique password for all shares to this team" : "为此团队的全部共享使用唯一密码",
     "Unique password …" : "独立密码 ...",
     "Save" : "保存",
     "Change unique password" : "修改独立密码",
     "Failed to save password. Please try again later." : "保存密码失败，请稍后重试。",
+    "An error happened during the config change" : "更改配置时发生一个错误",
     "There is no description for this team" : "此团队没有描述",
     "Enter a description for the team" : "输入团队的描述",
     "An error happened during description sync" : "描述同步期间发生一个错误",
     "An error happened during name sync" : "名称同步期间发生了一个错误",
-    "Team owned by {owner}" : "{owner} 拥有的团队",
-    "Team settings" : "团队设置",
+    "Team name" : "团队名称",
+    "Team owner" : "团队所有者",
+    "Edit" : "编辑",
+    "Cancel" : "取消",
     "Request to join" : "请求加入",
-    "Description" : "描述",
     "Your request to join this team is pending approval" : "您加入此团队的请求正在等待批准",
     "You are not a member of {circle}" : "您并非 {circle} 的成员",
-    "Team resources" : "团队资源",
-    "Anything shared with this team will show up here" : "与此团队共享的任何内容都将显示在此处",
-    "Team name" : "团队名称",
-    "Settings" : "设置",
-    "Actions" : "操作",
+    "Members" : "成员",
     "Confirm" : "确认",
-    "Cancel" : "取消",
     "Add more info" : "添加更多信息",
     "More fields" : "更多领域",
     "Please select a valid format" : "请选择有效格式",
@@ -149,7 +144,6 @@ OC.L10N.register(
     "Go to talk conversation" : "前往对话",
     "View profile" : "查看个人资料",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "此联系人资料损坏但已被修复。请查看内容并点击这里以保存它。",
-    "Edit" : "编辑",
     "Clone contact" : "克隆联系人",
     "Generate QR Code" : "生成二维码",
     "Contact vCard as QR code" : "联系人名片作为二维码",
@@ -179,16 +173,6 @@ OC.L10N.register(
     "Local team" : "本地团队",
     "This team will not be shared with the other instances of the global scale" : "此团队不会与全局范围内的其他实例共享",
     "Create team" : "创建团队",
-    "Unable to get the results" : "无法获得结果",
-    "Some members could not be added" : "无法添加一些成员",
-    "There was an issue adding members to the team" : "向团队添加成员时出现问题",
-    "Team members" : "团队成员",
-    "Loading members list …" : "正在加载成员列表 ...",
-    "The list of members is only visible to members of this team" : "成员列表仅对此团队的成员可见",
-    "You currently have no access to the member list" : "您目前无法访问成员列表",
-    "Add members" : "添加成员",
-    "Add to {circle}" : "添加到 {circle}",
-    "Pending" : "待定",
     "Promote as sole owner" : "提升为唯一所有人",
     "Promote to {level}" : "提升为 {level}",
     "Demote to {level}" : "降级为 {level}",
@@ -201,6 +185,14 @@ OC.L10N.register(
     "Reject membership request" : "拒绝成员身份请求",
     "Manage level" : "管理级别",
     "Remove member" : "删除成员",
+    "Unable to get the results" : "无法获得结果",
+    "Some members could not be added" : "无法添加一些成员",
+    "There was an issue adding members to the team" : "向团队添加成员时出现问题",
+    "Loading members list …" : "正在加载成员列表 ...",
+    "The list of members is only visible to members of this team" : "成员列表仅对此团队的成员可见",
+    "You currently have no access to the member list" : "您目前无法访问成员列表",
+    "Add to {circle}" : "添加到 {circle}",
+    "Pending" : "待定",
     "Select chart …" : "选择图表 ...",
     "Chart" : "图表",
     "Select Date" : "选择日期",
@@ -254,10 +246,10 @@ OC.L10N.register(
     "Members need to accept invitation" : "成员需要接受邀请",
     "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "成员资格必须由主持人确认/接受（要求“任何人都可以申请成员资格”）",
     "Members can also invite" : "成员也可以邀请",
-    "Visibility" : "可见性",
-    "Visible to everyone" : "对所有人可见",
-    "Team membership" : "团队成员",
+    "Membership" : "成员资格",
     "Prevent teams from being a member of another team" : "防止团队成为其他团队的成员",
+    "Privacy" : "隐私",
+    "Visible to everyone" : "对所有人可见",
     "users" : "用户",
     "Users" : "用户",
     "groups" : "群组",
@@ -330,6 +322,18 @@ OC.L10N.register(
     "An error has occurred in team(s). Check the console for more details." : "团队中出现错误。有关更多详情，请查看控制台。",
     "Unable to create team {circleName}" : "无法创建团队 {圈子名称}",
     "Unable to delete team {circleId}" : "无法删除团队 {circleId}",
-    "Unable to delete contact" : "无法删除联系人"
+    "Unable to delete contact" : "无法删除联系人",
+    "Password protection" : "密码保护",
+    "Team owned by {owner}" : "{owner} 拥有的团队",
+    "Team settings" : "团队设置",
+    "Description" : "描述",
+    "Team resources" : "团队资源",
+    "Anything shared with this team will show up here" : "与此团队共享的任何内容都将显示在此处",
+    "Settings" : "设置",
+    "Actions" : "操作",
+    "Team members" : "团队成员",
+    "Add members" : "添加成员",
+    "Visibility" : "可见性",
+    "Team membership" : "团队成员"
 },
 "nplurals=1; plural=0;");
