@@ -88,31 +88,26 @@ OC.L10N.register(
     "Sort by {sorting}" : "按 {sorting} 排序",
     "Manages" : "管理",
     "Oversees" : "監督",
-    "An error happened during the config change" : "變更設定時發生錯誤",
-    "Password protection" : "密碼保護",
     "Enforce password protection on files shared to this team" : "對分享到此團隊的檔案加上密碼保護",
     "Use a unique password for all shares to this team" : "對此團隊的所有分享使用獨一無二的密碼",
     "Unique password …" : "獨一無二的密碼……",
     "Save" : "儲存",
     "Change unique password" : "變更獨一無二的密碼",
     "Failed to save password. Please try again later." : "儲存密碼失敗。請稍後再試。",
+    "An error happened during the config change" : "變更設定時發生錯誤",
     "There is no description for this team" : "此團隊沒有描述",
     "Enter a description for the team" : "輸入團隊的描述",
     "An error happened during description sync" : "描述同步時發生錯誤",
     "An error happened during name sync" : "名稱同步時發生錯誤",
-    "Team owned by {owner}" : "{owner} 擁有的團隊",
-    "Team settings" : "團隊設定",
+    "Team name" : "團隊名稱",
+    "Team owner" : "團隊擁有者",
+    "Edit" : "編輯",
+    "Cancel" : "取消",
     "Request to join" : "要求加入",
-    "Description" : "描述",
     "Your request to join this team is pending approval" : "您加入此團隊的請求正在等待批准",
     "You are not a member of {circle}" : "您不是 {circle} 的成員",
-    "Team resources" : "團隊資源",
-    "Anything shared with this team will show up here" : "與此團隊分享的任何東西都會顯示在此處",
-    "Team name" : "團隊名稱",
-    "Settings" : "Settings",
-    "Actions" : "動作",
+    "Members" : "成員",
     "Confirm" : "確認",
-    "Cancel" : "取消",
     "Add more info" : "新增更多資訊",
     "More fields" : "更多欄位",
     "Please select a valid format" : "請選取有效格式",
@@ -149,7 +144,6 @@ OC.L10N.register(
     "Go to talk conversation" : "前往對話",
     "View profile" : "檢視個人檔案",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "此聯絡人的資料有問題，已修復。請審閱內容並點擊此處以儲存。",
-    "Edit" : "編輯",
     "Clone contact" : "再製連絡人",
     "Generate QR Code" : "產生 QR Code",
     "Contact vCard as QR code" : "QR Code 形式的聯絡人 vCard",
@@ -179,16 +173,6 @@ OC.L10N.register(
     "Local team" : "本地團隊",
     "This team will not be shared with the other instances of the global scale" : "這個團隊不會與全球的其他站台共享",
     "Create team" : "建立團隊",
-    "Unable to get the results" : "無法取得結果",
-    "Some members could not be added" : "無法新增部份成員",
-    "There was an issue adding members to the team" : "將成員新增至團隊時發生錯誤",
-    "Team members" : "團隊成員",
-    "Loading members list …" : "正在載入成員清單……",
-    "The list of members is only visible to members of this team" : "成員清單僅有此團隊的成員可見",
-    "You currently have no access to the member list" : "您目前無權存取成員清單",
-    "Add members" : "新增成員",
-    "Add to {circle}" : "新增至 {circle}",
-    "Pending" : "擱置中",
     "Promote as sole owner" : "將其權限升級為唯一擁有者",
     "Promote to {level}" : "將其權限升級為 {level}",
     "Demote to {level}" : "將其權限降級為 {level}",
@@ -201,6 +185,14 @@ OC.L10N.register(
     "Reject membership request" : "拒絕成員資格請求",
     "Manage level" : "管理等級",
     "Remove member" : "移除成員",
+    "Unable to get the results" : "無法取得結果",
+    "Some members could not be added" : "無法新增部份成員",
+    "There was an issue adding members to the team" : "將成員新增至團隊時發生錯誤",
+    "Loading members list …" : "正在載入成員清單……",
+    "The list of members is only visible to members of this team" : "成員清單僅有此團隊的成員可見",
+    "You currently have no access to the member list" : "您目前無權存取成員清單",
+    "Add to {circle}" : "新增至 {circle}",
+    "Pending" : "擱置中",
     "Select chart …" : "選取圖表……",
     "Chart" : "圖表",
     "Select Date" : "選取日期",
@@ -254,10 +246,10 @@ OC.L10N.register(
     "Members need to accept invitation" : "成員必須接受邀請",
     "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "成員資格必須由主持人確認／接受（必須為「任何人都可以請求成員資格）",
     "Members can also invite" : "成員也可以邀請",
-    "Visibility" : "能見度",
-    "Visible to everyone" : "對所有人可見",
-    "Team membership" : "團隊成員資格",
+    "Membership" : "成員",
     "Prevent teams from being a member of another team" : "避免團隊成為其他團隊的成員",
+    "Privacy" : "隱私權",
+    "Visible to everyone" : "對所有人可見",
     "users" : "使用者",
     "Users" : "使用者",
     "groups" : "群組",
@@ -330,6 +322,18 @@ OC.L10N.register(
     "An error has occurred in team(s). Check the console for more details." : "團隊中出現錯誤。請檢查主控台以取得更多詳細資訊。",
     "Unable to create team {circleName}" : "無法建立團隊 {circleName}",
     "Unable to delete team {circleId}" : "無法刪除團隊 {circleId}",
-    "Unable to delete contact" : "無法刪除聯絡人"
+    "Unable to delete contact" : "無法刪除聯絡人",
+    "Password protection" : "密碼保護",
+    "Team owned by {owner}" : "{owner} 擁有的團隊",
+    "Team settings" : "團隊設定",
+    "Description" : "描述",
+    "Team resources" : "團隊資源",
+    "Anything shared with this team will show up here" : "與此團隊分享的任何東西都會顯示在此處",
+    "Settings" : "Settings",
+    "Actions" : "動作",
+    "Team members" : "團隊成員",
+    "Add members" : "新增成員",
+    "Visibility" : "能見度",
+    "Team membership" : "團隊成員資格"
 },
 "nplurals=1; plural=0;");
